# qibojit

![Tests](https://github.com/qiboteam/qibojit/workflows/Tests/badge.svg)
[![codecov](https://codecov.io/gh/qiboteam/qibojit/branch/main/graph/badge.svg?token=580GFLLFNN)](https://codecov.io/gh/qiboteam/qibojit)
[![Documentation Status](https://readthedocs.org/projects/qibo/badge/?version=latest)](https://qibo.readthedocs.io/en/latest/?badge=latest)
[![DOI](https://zenodo.org/badge/360678684.svg)](https://zenodo.org/badge/latestdoi/360678684)

This package provides acceleration features for [Qibo](https://github.com/qiboteam/qibo) simulations using just-in-time (JIT) custom kernel with [numba](https://numba.pydata.org/), [cupy](https://cupy.dev/) and [cuQuantum](https://developer.nvidia.com/cuquantum-sdk).

## Documentation

The qibojit backend documentation is available at [qibo.science](https://qibo.science/qibo/stable/getting-started/installation.html).

## Citation policy

If you use the package please refer to [the documentation](https://qibo.science/qibo/stable/appendix/citing-qibo.html) for citation instructions.
